==> haskell-dlist-instances-0.1.1.1-283-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dlist-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dlist-instances
version:              0.1.1.1
visibility:           public
id:                   dlist-instances-0.1.1.1-IprenjAupJyEkLRXNMBQVZ
key:                  dlist-instances-0.1.1.1-IprenjAupJyEkLRXNMBQVZ
license:              BSD-3-Clause
copyright:            2013 Greg Weber
maintainer:           Greg Weber <greg@gregweber.info>
author:               Greg Weber
homepage:             https://github.com/gregwebs/dlist-instances
synopsis:             Difference lists instances
description:
    See the dlist packages.
    This package is the canonical source for some orphan instances.
    Orphan instances are placed here to avoid dependencies elsewhere.

category:             Data
abi:                  2feb8f2ae365b759537ee506b501e1b7
exposed:              True
exposed-modules:      Data.DList.Instances
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dlist-instances-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dlist-instances-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dlist-instances-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dlist-instances
hs-libraries:         HSdlist-instances-0.1.1.1-IprenjAupJyEkLRXNMBQVZ
depends:              base-4.17.2.1 dlist-1.0-EiEX2RUghzF8pZkpOiFw2B
haddock-interfaces:
    /usr/share/doc/haskell-dlist-instances/html/dlist-instances.haddock

haddock-html:         /usr/share/doc/haskell-dlist-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dlist-instances-0.1.1.1-289-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dlist-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dlist-instances
version:              0.1.1.1
visibility:           public
id:                   dlist-instances-0.1.1.1-D2Ook8VBLip26sSJkToavL
key:                  dlist-instances-0.1.1.1-D2Ook8VBLip26sSJkToavL
license:              BSD-3-Clause
copyright:            2013 Greg Weber
maintainer:           Greg Weber <greg@gregweber.info>
author:               Greg Weber
homepage:             https://github.com/gregwebs/dlist-instances
synopsis:             Difference lists instances
description:
    See the dlist packages.
    This package is the canonical source for some orphan instances.
    Orphan instances are placed here to avoid dependencies elsewhere.

category:             Data
abi:                  823078b9876625d98cdc8e6c4c9b135d
exposed:              True
exposed-modules:      Data.DList.Instances
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dlist-instances-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dlist-instances-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dlist-instances-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dlist-instances
hs-libraries:         HSdlist-instances-0.1.1.1-D2Ook8VBLip26sSJkToavL
depends:              base-4.17.2.1 dlist-1.0-4JevPcHjuIUFMGxCSM81ml
haddock-interfaces:
    /usr/share/doc/haskell-dlist-instances/html/dlist-instances.haddock

haddock-html:         /usr/share/doc/haskell-dlist-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
